==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/admin/messages/es/settings.php <==
<?php

return [
    '1 month' => '1 mes',
    '1 week' => '1 semana',
    '1 year' => '1 año',
    '2 weeks' => '2 semanas',
    '3 months' => '3 meses',
    '6 months' => '6 meses',
    '<strong>Confirm</strong> icon deletion' => '<strong>Confirma</strong> el borrado del icono',
    '<strong>Confirm</strong> image deletion' => '<strong>Confirmar</strong> borrar imagen',
    '<strong>Maintenance</strong> Mode' => 'Modo<strong> Mantenimiento</strong>',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Advertencia:</strong> todos los usuarios se cerrarán inmediatamente, excepto los administradores.',
    'APC(u)' => 'APC(u)',
    'Activate' => 'Activar',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => '¿Activar el modo de mantenimiento y deshabilitar el acceso a la plataforma para usuarios que no sean administradores? <br><br>',
    'Add OEmbed provider' => 'Agregar proveedor de OEmbed',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Agregue texto de información personalizado para el modo de mantenimiento. Se muestra en la página de inicio de sesión.',
    'Add new provider' => 'Añadir nuevo proveedor',
    'Advanced Settings' => 'Ajustes avanzados',
    'Allow Self-Signed Certificates?' => '¿Permitir cerfificados autofirmados?',
    'Allowed file extensions' => 'Extensiones de archivos permitidas',
    'Alphabetical' => 'Alfabético',
    'Appearance Settings' => 'Ajustes de apariencia',
    'Auto format based on user language - Example: {example}' => 'Formato automático basado en el lenguaje del usuario - Ejemplo: {example}',
    'Back to overview' => 'Regresar a la vista previa',
    'Base URL' => 'URL Base',
    'Cache Backend' => 'Modo de caché',
    'Comma separated list. Leave empty to allow all.' => 'Lista separada por comas. Deja en blanco para permitir todos',
    'Could not send test email.' => 'El envío de correo electrónico de prueba no fue exitoso.',
    'Currently no provider active!' => '¡No hay ningún proveedor activo!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Actualmente hay {count} registros en la base de datos que data de {dating}.',
    'Dashboard' => 'Inicio',
    'Date input format' => 'Formato de fecha',
    'Deactivate' => 'Desactivar',
    'Deactivate maintenance mode and enable all users to access the platform again?' => '¿Desactivar el modo de mantenimiento y permitir que todos los usuarios vuelvan a acceder a la plataforma?',
    'Default Expire Time (in seconds)' => 'Tiempo de expiración por defecto (en segundos)',
    'Default Timezone' => 'Zona horaria por defecto',
    'Default language' => 'Idioma por defecto',
    'Default pagination size (Entries per page)' => 'Tamaño de paginación por defecto (Entradas por página)',
    'Default stream content order' => 'Orden del contenido de Actividad',
    'Delete' => 'Eliminar',
    'Display Name (Format)' => 'Mostrar nombre (Formato)',
    'Dropdown space order' => 'Orden de los desplegables',
    'E-Mail' => 'Correo electrónico',
    'E-Mail reply-to' => 'Dirección de respuesta',
    'E-Mail sender address' => 'Dirección del remitente del correo electrónico',
    'E-Mail sender name' => 'Nombre del remitente del correo electrónico',
    'E.g. http://example.com/humhub' => 'P.ej. http://example.com/humhub',
    'Edit OEmbed provider' => 'Editar proveedor de OEmbed',
    'Enable maintenance mode' => 'Habilitar el modo de mantenimiento',
    'Enable user friendship system' => 'Activar el Sistema de Amigos',
    'Enabled' => 'Habilitado',
    'Enabled OEmbed providers' => 'Proveedores de OEmbed activados',
    'Encryption' => 'Cifrado',
    'Endpoint Url' => 'Endpoint URL',
    'Exclude media files from stream attachment list' => 'Excluir los archivos de medios de la lista de archivos vinculados de Actividad',
    'File' => 'Archivo',
    'Firstname Lastname (e.g. John Doe)' => 'Nombre y Apellido (p.ej. John Doe)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Formato fijo (dd/mm/aaaa) - Ejemplo: {example}',
    'Friendship' => 'Amistad',
    'General' => 'General',
    'General Settings' => 'Ajustes generales',
    'HTML tracking code' => 'Código de seguimiento HTML',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Aquí puede configurar el comportamiento de registro y la configuración de usuario adicional de su red social.',
    'Here you can configure basic settings of your social network.' => 'Aquí puede configurar los ajustes básicos de su red social.',
    'Horizontal scrolling images on a mobile device' => 'Desplazamiento horizontal en dispositivos móviles',
    'Icon upload' => 'Subir icono',
    'Last visit' => 'Última visita',
    'Logo upload' => 'Subir logo',
    'Mail Transport Type' => 'Tipo de transporte de correo',
    'Maintenance mode' => 'Modo de mantenimiento',
    'Maximum allowed age for logs.' => 'Edad máxima para los logs.',
    'Maximum upload file size (in MB)' => 'Tamaño máximo de archivo para subir (en MB)',
    'Mobile appearance' => 'Apariencia móvil',
    'Name of the application' => 'Nombre de la aplicación',
    'No Proxy Hosts' => 'Sin Proxy',
    'No caching' => 'No hacer caché',
    'Notification Settings' => 'Configuración de las notificaciones',
    'Old logs can significantly increase the size of your database while providing little information.' => 'Registros antiguos pueden aumentar significativamente el tamaño de su base de datos, proporcionando poca información.',
    'Optional. Default reply address for system emails like notifications.' => 'Opcional. Dirección de correo electrónico para los mensajes del sistema, como las notificaciones.',
    'PHP APC(u) Extension missing - Type not available!' => 'La extensión PHP APC(u) no está disponible - ¡Tipo no disponible!',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHP reportó un máximo de {maxUploadSize} MB',
    'Password' => 'Contraseña',
    'Port' => 'Puerto',
    'Port number' => 'Número de puerto',
    'Prevent client caching of following scripts' => 'Evitar el almacenamiento en caché del cliente de los siguientes scripts',
    'Redis' => 'Redis',
    'Reported database time: {dateTime}' => 'Hora de la base de datos informada: {dateTime}',
    'SMTP Options' => 'Opciones SMTP',
    'Save' => 'Guardar',
    'Save & Flush Caches' => 'Guardar y vaciar cachés',
    'Save & Test' => 'Guardar y probar',
    'Saved' => 'Guardado',
    'Saved and flushed cache' => 'Guardado y vaciada la caché',
    'Saved and sent test email to: {address}' => 'Cambios guardados y correo de prueba enviado a: {address}',
    'Server' => 'Servidor',
    'Server Timezone' => 'Zona horaria del Servidor',
    'Show introduction tour for new users' => 'Mostrar guía de introducción a los nuevos usuarios',
    'Show user profile post form on dashboard' => 'Mostrar el formulario para escribir entradas en Inicio',
    'Sort by creation date' => 'Ordenar por fecha de creación',
    'Sort by update date' => 'Ordenar por fecha de actualización',
    'Test message' => 'Mensaje de prueba',
    'Theme' => 'Tema',
    'These settings refer to advanced topics of your social network.' => 'Estos ajustes se refieren a temas avanzados de su red social.',
    'These settings refer to the appearance of your social network.' => 'Estos ajustes se refieren a la apariencia de su red social.',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Usa %url% como marcador para la URL. El formato necesario es JSON. (p.ej. http://www.youtube.com/oembed?url=%url%&amp;format=json)',
    'Use X-Sendfile for File Downloads' => 'Usar X-Sendfile para las descargas de archivos',
    'Use the default swipe to show sidebar on a mobile device' => 'Use el deslizamiento predeterminado para mostrar la barra lateral en un dispositivo móvil',
    'User' => 'Usuario',
    'User Settings' => 'Ajustes de usuario',
    'Username' => 'Usuario',
    'Username (e.g. john)' => 'Usuario (p.ej. john)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Puede agregar un fragmento de código HTML de estadísticas, que se agregará a todas las páginas renderizadas.',
    'You\'re using no icon at the moment. Upload your logo now.' => 'No estás usando ningún icono en este momento. Sube tu logo ahora.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'No estás usando un logo ahora. Sube tu logo ahora.',
    'never' => 'nunca',
    'Access Token' => '',
    'Access token is not provided yet.' => '',
    'Embedded content requires the user\'s consent to be loaded' => '',
    'Provider Name' => '',
    'Regular expression by which the link match will be checked.' => '',
    'Url Pattern' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/modules/admin/messages/es/settings.php <==
<?php

return [
    '1 month' => '1 mes',
    '1 week' => '1 semana',
    '1 year' => '1 año',
    '2 weeks' => '2 semanas',
    '3 months' => '3 meses',
    '6 months' => '6 meses',
    '<strong>Confirm</strong> icon deletion' => '<strong>Confirma</strong> el borrado del icono',
    '<strong>Confirm</strong> image deletion' => '<strong>Confirmar</strong> borrar imagen',
    '<strong>Maintenance</strong> Mode' => 'Modo<strong> Mantenimiento</strong>',
    '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Advertencia:</strong> todos los usuarios se cerrarán inmediatamente, excepto los administradores.',
    'Access Token' => 'Token de acceso',
    'Access token is not provided yet.' => 'Todavía no se ha proporcionado un token de acceso.',
    'Activate' => 'Activar',
    'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => '¿Activar el modo de mantenimiento y deshabilitar el acceso a la plataforma para usuarios que no sean administradores? <br><br>',
    'Add OEmbed provider' => 'Agregar proveedor de OEmbed',
    'Add custom info text for maintenance mode. Displayed on the login page.' => 'Agregue texto de información personalizado para el modo de mantenimiento. Se muestra en la página de inicio de sesión.',
    'Add new provider' => 'Añadir nuevo proveedor',
    'Advanced Settings' => 'Ajustes avanzados',
    'Allow Self-Signed Certificates?' => '¿Permitir cerfificados autofirmados?',
    'Allowed file extensions' => 'Extensiones de archivos permitidas',
    'Alphabetical' => 'Alfabético',
    'Appearance Settings' => 'Ajustes de apariencia',
    'Auto format based on user language - Example: {example}' => 'Formato automático basado en el lenguaje del usuario - Ejemplo: {example}',
    'Back to overview' => 'Regresar a la vista previa',
    'Base URL' => 'URL Base',
    'Comma separated list. Leave empty to allow all.' => 'Lista separada por comas. Deja en blanco para permitir todos',
    'Configuration (Use settings from configuration file)' => 'Configuración (utiliza valores del fichero de configuración)',
    'Could not send test email.' => 'El envío de correo electrónico de prueba no fue exitoso.',
    'Currently no provider active!' => '¡No hay ningún proveedor activo!',
    'Currently there are {count} records in the database dating from {dating}.' => 'Actualmente hay {count} registros en la base de datos que data de {dating}.',
    'Custom DSN' => 'DSN personalizado',
    'DSN' => 'DSN',
    'DSN Examples:' => 'Ejemplos de DSN:',
    'Dashboard' => 'Inicio',
    'Date input format' => 'Formato de fecha',
    'Deactivate' => 'Desactivar',
    'Deactivate maintenance mode and enable all users to access the platform again?' => '¿Desactivar el modo de mantenimiento y permitir que todos los usuarios vuelvan a acceder a la plataforma?',
    'Default Timezone' => 'Zona horaria por defecto',
    'Default language' => 'Idioma por defecto',
    'Default pagination size (Entries per page)' => 'Tamaño de paginación por defecto (Entradas por página)',
    'Default stream content order' => 'Orden del contenido de Actividad',
    'Delete' => 'Eliminar',
    'Dropdown space order' => 'Orden de los desplegables',
    'E-Mail' => 'Correo electrónico',
    'E-Mail reply-to' => 'Dirección de respuesta',
    'E-Mail sender address' => 'Dirección del remitente del correo electrónico',
    'E-Mail sender name' => 'Nombre del remitente del correo electrónico',
    'E.g. http://example.com/humhub' => 'P.ej. http://example.com/humhub',
    'Edit OEmbed provider' => 'Editar proveedor de OEmbed',
    'Embedded content requires the user\'s consent to be loaded' => 'La carga de contenido incrustado requiere el permiso del usuario',
    'Enable maintenance mode' => 'Habilitar el modo de mantenimiento',
    'Enable user friendship system' => 'Activar el Sistema de Amigos',
    'Enabled' => 'Habilitado',
    'Enabled OEmbed providers' => 'Proveedores de OEmbed activados',
    'Endpoint Url' => 'Endpoint URL',
    'Exclude media files from stream attachment list' => 'Excluir los archivos de medios de la lista de archivos vinculados de Actividad',
    'Firstname Lastname (e.g. John Doe)' => 'Nombre y Apellido (p.ej. John Doe)',
    'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Formato fijo (dd/mm/aaaa) - Ejemplo: {example}',
    'Friendship' => 'Amistad',
    'General' => 'General',
    'General Settings' => 'Ajustes generales',
    'HTML tracking code' => 'Código de seguimiento HTML',
    'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Aquí puede configurar el comportamiento de registro y la configuración de usuario adicional de su red social.',
    'Here you can configure basic settings of your social network.' => 'Aquí puede configurar los ajustes básicos de su red social.',
    'Horizontal scrolling images on a mobile device' => 'Desplazamiento horizontal en dispositivos móviles',
    'Icon upload' => 'Subir icono',
    'Last visit' => 'Última visita',
    'Logo upload' => 'Subir logo',
    'Mail Transport Type' => 'Tipo de transporte de correo',
    'Maintenance mode' => 'Modo de mantenimiento',
    'Maximum allowed age for logs.' => 'Edad máxima para los logs.',
    'Maximum upload file size (in MB)' => 'Tamaño máximo de archivo para subir (en MB)',
    'Mobile appearance' => 'Apariencia móvil',
    'Name of the application' => 'Nombre de la aplicación',
    'No Delivery (Debug Mode, Save as file)' => 'Sin entrega (modo de depuración, guarda como fichero)',
    'No Proxy Hosts' => 'Sin Proxy',
    'Notification Settings' => 'Configuración de las notificaciones',
    'Old logs can significantly increase the size of your database while providing little information.' => 'Registros antiguos pueden aumentar significativamente el tamaño de su base de datos, proporcionando poca información.',
    'Optional. Default reply address for system emails like notifications.' => 'Opcional. Dirección de correo electrónico para los mensajes del sistema, como las notificaciones.',
    'PHP (Use settings of php.ini file)' => 'PHP (utiliza los valores del fichero php.ini)',
    'PHP reported a maximum of {maxUploadSize} MB' => 'PHP reportó un máximo de {maxUploadSize} MB',
    'Password' => 'Contraseña',
    'Port' => 'Puerto',
    'Port number' => 'Número de puerto',
    'Provider Name' => 'Nombre del proveedor',
    'Regular expression by which the link match will be checked.' => 'Expresión regular con la que comprobar el enlace.',
    'Reported database time: {dateTime}' => 'Hora de la base de datos informada: {dateTime}',
    'Save' => 'Guardar',
    'Save & Flush Caches' => 'Guardar y vaciar cachés',
    'Save & Test' => 'Guardar y probar',
    'Saved' => 'Guardado',
    'Saved and flushed cache' => 'Guardado y vaciada la caché',
    'Saved and sent test email to: {address}' => 'Cambios guardados y correo de prueba enviado a: {address}',
    'Server' => 'Servidor',
    'Server Timezone' => 'Zona horaria del Servidor',
    'Show introduction tour for new users' => 'Mostrar guía de introducción a los nuevos usuarios',
    'Show user profile post form on dashboard' => 'Mostrar el formulario para escribir entradas en Inicio',
    'Sort by creation date' => 'Ordenar por fecha de creación',
    'Sort by update date' => 'Ordenar por fecha de actualización',
    'Test message' => 'Mensaje de prueba',
    'Theme' => 'Tema',
    'These settings refer to advanced topics of your social network.' => 'Estos ajustes se refieren a temas avanzados de su red social.',
    'These settings refer to the appearance of your social network.' => 'Estos ajustes se refieren a la apariencia de su red social.',
    'Url Pattern' => 'Patrón de URL',
    'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Usa %url% como marcador para la URL. El formato necesario es JSON. (p.ej. http://www.youtube.com/oembed?url=%url%&amp;format=json)',
    'Use SMTPS' => 'Utilizar SMTPS',
    'Use X-Sendfile for File Downloads' => 'Usar X-Sendfile para las descargas de archivos',
    'User' => 'Usuario',
    'User Display Name' => 'Nombre de usuario que se muestra',
    'User Display Name Subtitle' => 'Subtítulo de usuario que se muestra',
    'User Settings' => 'Ajustes de usuario',
    'Username' => 'Usuario',
    'Username (e.g. john)' => 'Usuario (p.ej. john)',
    'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Puede agregar un fragmento de código HTML de estadísticas, que se agregará a todas las páginas renderizadas.',
    'You can find more configuration options here:' => 'Aquí puedes encontrar más opciones de configuración:',
    'You\'re using no icon at the moment. Upload your logo now.' => 'No estás usando ningún icono en este momento. Sube tu logo ahora.',
    'You\'re using no logo at the moment. Upload your logo now.' => 'No estás usando un logo ahora. Sube tu logo ahora.',
    'e.g. 25 (for SMTP) or 465 (for SMTPS)' => 'p. ej. 25 (para SMTP) o 465 (para SMTPS)',
    'e.g. localhost' => 'p. ej. localhost',
    'e.g. smtps://user:pass@smtp.example.com:port' => 'p. ej smtps://user:pass@smtp.ejemplo.com:puerto',
    'never' => 'nunca',
    'Inserted script tags must contain a nonce. e.g. {code}' => '',
];
